@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "json-process-client" "0.2.0"
+(define-package "json-process-client" "20250330.728"
   "Interact with a TCP process using JSON."
-  '((emacs "25.1"))
-  :url "https://gitlab.petton.fr/nico/json-process-client"
-  :commit "1d4a1fe2ecc682890dfc75e40054c9697c3046f6"
-  :revdesc "v0.2.0-0-g1d4a1fe2ecc6"
+  '((emacs "27.1"))
+  :url "https://github.com/DamienCassou/json-process-client"
+  :commit "6485953fe6eff62938fd08720811c6fdd09d7d22"
+  :revdesc "6485953fe6ef"
   :authors '(("Nicolas Petton" . "nicolas@petton.fr")
              ("Damien Cassou" . "damien@cassou.me"))
   :maintainers '(("Nicolas Petton" . "nicolas@petton.fr")
